/************************************************************************
 * This program is Copyright (C) 1986-1996 by Jonathan Payne.  JOVE is  *
 * provided to you without charge, and with no warranty.  You may give  *
 * away copies of JOVE, including sources, provided that this notice is *
 * included in all the files.                                           *
 ************************************************************************/

/* keys.c is derived from keys.txt by setmaps */

/* Only edit keys.txt, not keys.c.
 *
 * keys.txt is processed as text by setmaps.  This means that what follows
 * is a very restricted subset of C.
 *
 * - Lines beginning with "#if", "#else", and "#endif" are understood
 *   to be the parts of conditional compilation.
 *   They will not be recognized if they are "spelled" differently
 *   (say, with whitespace).  Generally, there ought to be the same
 *   number of table entries in each branch of the if.
 *
 * - On a Mac, lines begining with "#MENU" are used to specify that
 *   the table is for a menu.
 *
 * - Lines begining with a tab followed by a " are treated as table entries.
 *
 * - Other lines are passed through, and are assumed to delimit tables.
 *   This means that they must not be within tables.
 */

#include "jove.h"
#include "commands.h"

data_obj *MainKeys[NCHARS] = {
	(data_obj *) &commands[188],	/* ^@ */
	(data_obj *) &commands[16],	/* ^A */
	(data_obj *) &commands[7],	/* ^B */
	(data_obj *) NULL,		/* ^C */
	(data_obj *) &commands[44],	/* ^D */
	(data_obj *) &commands[70],	/* ^E */
	(data_obj *) &commands[87],	/* ^F */
	(data_obj *) NULL,		/* ^G */
	(data_obj *) &commands[46],	/* ^H */
	(data_obj *) &commands[99],	/* ^I */
	(data_obj *) &commands[126],	/* ^J */
	(data_obj *) &commands[112],	/* ^K */
	(data_obj *) &commands[161],	/* ^L */
	(data_obj *) &commands[124],	/* ^M */
	(data_obj *) &commands[128],	/* ^N */
	(data_obj *) &commands[125],	/* ^O */
	(data_obj *) &commands[141],	/* ^P */
	(data_obj *) &commands[157],	/* ^Q */
	(data_obj *) &commands[173],	/* ^R */
	(data_obj *) &commands[171],	/* ^S */
	(data_obj *) &commands[207],	/* ^T */
	(data_obj *) &commands[94],	/* ^U */
	(data_obj *) &commands[129],	/* ^V */
	(data_obj *) &commands[108],	/* ^W */
	(data_obj *) NULL,		/* ^X */
	(data_obj *) &commands[234],	/* ^Y */
	(data_obj *) &commands[170],	/* ^Z */
	(data_obj *) NULL,		/* ESC */
#ifdef MAC	/* peculiar cursor key codes */
	(data_obj *) &commands[7],	/* ^\ */
	(data_obj *) &commands[87],	/* ^] */
	(data_obj *) &commands[141],	/* ^^ */
	(data_obj *) &commands[128],	/* ^_ */
#else
	(data_obj *) &commands[171],	/* ^\ */
	(data_obj *) &commands[85],	/* ^] */
	(data_obj *) &commands[157],	/* ^^ */
	(data_obj *) NULL,		/* ^_ */
#endif
	(data_obj *) &commands[186],	/*   */
	(data_obj *) &commands[186],	/* ! */
	(data_obj *) &commands[186],	/* " */
	(data_obj *) &commands[186],	/* # */
	(data_obj *) &commands[186],	/* $ */
	(data_obj *) &commands[186],	/* % */
	(data_obj *) &commands[186],	/* & */
	(data_obj *) &commands[186],	/* ' */
	(data_obj *) &commands[186],	/* ( */
	(data_obj *) &commands[134],	/* ) */
	(data_obj *) &commands[186],	/* * */
	(data_obj *) &commands[186],	/* + */
	(data_obj *) &commands[186],	/* , */
	(data_obj *) &commands[186],	/* - */
	(data_obj *) &commands[186],	/* . */
	(data_obj *) &commands[186],	/* / */
	(data_obj *) &commands[186],	/* 0 */
	(data_obj *) &commands[186],	/* 1 */
	(data_obj *) &commands[186],	/* 2 */
	(data_obj *) &commands[186],	/* 3 */
	(data_obj *) &commands[186],	/* 4 */
	(data_obj *) &commands[186],	/* 5 */
	(data_obj *) &commands[186],	/* 6 */
	(data_obj *) &commands[186],	/* 7 */
	(data_obj *) &commands[186],	/* 8 */
	(data_obj *) &commands[186],	/* 9 */
	(data_obj *) &commands[186],	/* : */
	(data_obj *) &commands[186],	/* ; */
	(data_obj *) &commands[186],	/* < */
	(data_obj *) &commands[186],	/* = */
	(data_obj *) &commands[186],	/* > */
	(data_obj *) &commands[186],	/* ? */
	(data_obj *) &commands[186],	/* @ */
	(data_obj *) &commands[186],	/* A */
	(data_obj *) &commands[186],	/* B */
	(data_obj *) &commands[186],	/* C */
	(data_obj *) &commands[186],	/* D */
	(data_obj *) &commands[186],	/* E */
	(data_obj *) &commands[186],	/* F */
	(data_obj *) &commands[186],	/* G */
	(data_obj *) &commands[186],	/* H */
	(data_obj *) &commands[186],	/* I */
	(data_obj *) &commands[186],	/* J */
	(data_obj *) &commands[186],	/* K */
	(data_obj *) &commands[186],	/* L */
	(data_obj *) &commands[186],	/* M */
	(data_obj *) &commands[186],	/* N */
	(data_obj *) &commands[186],	/* O */
	(data_obj *) &commands[186],	/* P */
	(data_obj *) &commands[186],	/* Q */
	(data_obj *) &commands[186],	/* R */
	(data_obj *) &commands[186],	/* S */
	(data_obj *) &commands[186],	/* T */
	(data_obj *) &commands[186],	/* U */
	(data_obj *) &commands[186],	/* V */
	(data_obj *) &commands[186],	/* W */
	(data_obj *) &commands[186],	/* X */
	(data_obj *) &commands[186],	/* Y */
	(data_obj *) &commands[186],	/* Z */
	(data_obj *) &commands[186],	/* [ */
	(data_obj *) &commands[186],	/* \ */
	(data_obj *) &commands[134],	/* ] */
	(data_obj *) &commands[186],	/* ^ */
	(data_obj *) &commands[186],	/* _ */
	(data_obj *) &commands[186],	/* ` */
	(data_obj *) &commands[186],	/* a */
	(data_obj *) &commands[186],	/* b */
	(data_obj *) &commands[186],	/* c */
	(data_obj *) &commands[186],	/* d */
	(data_obj *) &commands[186],	/* e */
	(data_obj *) &commands[186],	/* f */
	(data_obj *) &commands[186],	/* g */
	(data_obj *) &commands[186],	/* h */
	(data_obj *) &commands[186],	/* i */
	(data_obj *) &commands[186],	/* j */
	(data_obj *) &commands[186],	/* k */
	(data_obj *) &commands[186],	/* l */
	(data_obj *) &commands[186],	/* m */
	(data_obj *) &commands[186],	/* n */
	(data_obj *) &commands[186],	/* o */
	(data_obj *) &commands[186],	/* p */
	(data_obj *) &commands[186],	/* q */
	(data_obj *) &commands[186],	/* r */
	(data_obj *) &commands[186],	/* s */
	(data_obj *) &commands[186],	/* t */
	(data_obj *) &commands[186],	/* u */
	(data_obj *) &commands[186],	/* v */
	(data_obj *) &commands[186],	/* w */
	(data_obj *) &commands[186],	/* x */
	(data_obj *) &commands[186],	/* y */
	(data_obj *) &commands[186],	/* z */
	(data_obj *) &commands[186],	/* { */
	(data_obj *) &commands[186],	/* | */
	(data_obj *) &commands[134],	/* } */
	(data_obj *) &commands[186],	/* ~ */
	(data_obj *) &commands[46],	/* ^? */
#if NCHARS != 128
	(data_obj *) &commands[186],	/* M-^@ */
	(data_obj *) &commands[186],	/* M-^A */
	(data_obj *) &commands[186],	/* M-^B */
	(data_obj *) &commands[186],	/* M-^C */
	(data_obj *) &commands[186],	/* M-^D */
	(data_obj *) &commands[186],	/* M-^E */
	(data_obj *) &commands[186],	/* M-^F */
	(data_obj *) &commands[186],	/* M-^G */
	(data_obj *) &commands[186],	/* M-^H */
	(data_obj *) &commands[186],	/* M-^I */
	(data_obj *) &commands[186],	/* M-^J */
	(data_obj *) &commands[186],	/* M-^K */
	(data_obj *) &commands[186],	/* M-^L */
	(data_obj *) &commands[186],	/* M-^M */
	(data_obj *) &commands[186],	/* M-^N */
	(data_obj *) &commands[186],	/* M-^O */
	(data_obj *) &commands[186],	/* M-^P */
	(data_obj *) &commands[186],	/* M-^Q */
	(data_obj *) &commands[186],	/* M-^R */
	(data_obj *) &commands[186],	/* M-^S */
	(data_obj *) &commands[186],	/* M-^T */
	(data_obj *) &commands[186],	/* M-^U */
	(data_obj *) &commands[186],	/* M-^V */
	(data_obj *) &commands[186],	/* M-^W */
	(data_obj *) &commands[186],	/* M-^X */
	(data_obj *) &commands[186],	/* M-^Y */
	(data_obj *) &commands[186],	/* M-^Z */
	(data_obj *) &commands[186],	/* M-ESC */
	(data_obj *) &commands[186],	/* M-^\ */
	(data_obj *) &commands[186],	/* M-^] */
	(data_obj *) &commands[186],	/* M-^^ */
	(data_obj *) &commands[186],	/* M-^_ */
	(data_obj *) &commands[186],	/* M-  */
	(data_obj *) &commands[186],	/* M-! */
	(data_obj *) &commands[186],	/* M-" */
	(data_obj *) &commands[186],	/* M-# */
	(data_obj *) &commands[186],	/* M-$ */
	(data_obj *) &commands[186],	/* M-% */
	(data_obj *) &commands[186],	/* M-& */
	(data_obj *) &commands[186],	/* M-' */
	(data_obj *) &commands[186],	/* M-( */
	(data_obj *) &commands[186],	/* M-) */
	(data_obj *) &commands[186],	/* M-* */
	(data_obj *) &commands[186],	/* M-+ */
	(data_obj *) &commands[186],	/* M-, */
	(data_obj *) &commands[186],	/* M-- */
	(data_obj *) &commands[186],	/* M-. */
	(data_obj *) &commands[186],	/* M-/ */
	(data_obj *) &commands[186],	/* M-0 */
	(data_obj *) &commands[186],	/* M-1 */
	(data_obj *) &commands[186],	/* M-2 */
	(data_obj *) &commands[186],	/* M-3 */
	(data_obj *) &commands[186],	/* M-4 */
	(data_obj *) &commands[186],	/* M-5 */
	(data_obj *) &commands[186],	/* M-6 */
	(data_obj *) &commands[186],	/* M-7 */
	(data_obj *) &commands[186],	/* M-8 */
	(data_obj *) &commands[186],	/* M-9 */
	(data_obj *) &commands[186],	/* M-: */
	(data_obj *) &commands[186],	/* M-; */
	(data_obj *) &commands[186],	/* M-< */
	(data_obj *) &commands[186],	/* M-= */
	(data_obj *) &commands[186],	/* M-> */
	(data_obj *) &commands[186],	/* M-? */
	(data_obj *) &commands[186],	/* M-@ */
	(data_obj *) &commands[186],	/* M-A */
	(data_obj *) &commands[186],	/* M-B */
	(data_obj *) &commands[186],	/* M-C */
	(data_obj *) &commands[186],	/* M-D */
	(data_obj *) &commands[186],	/* M-E */
	(data_obj *) &commands[186],	/* M-F */
	(data_obj *) &commands[186],	/* M-G */
	(data_obj *) &commands[186],	/* M-H */
	(data_obj *) &commands[186],	/* M-I */
	(data_obj *) &commands[186],	/* M-J */
	(data_obj *) &commands[186],	/* M-K */
	(data_obj *) &commands[186],	/* M-L */
	(data_obj *) &commands[186],	/* M-M */
	(data_obj *) &commands[186],	/* M-N */
	(data_obj *) &commands[186],	/* M-O */
	(data_obj *) &commands[186],	/* M-P */
	(data_obj *) &commands[186],	/* M-Q */
	(data_obj *) &commands[186],	/* M-R */
	(data_obj *) &commands[186],	/* M-S */
	(data_obj *) &commands[186],	/* M-T */
	(data_obj *) &commands[186],	/* M-U */
	(data_obj *) &commands[186],	/* M-V */
	(data_obj *) &commands[186],	/* M-W */
	(data_obj *) &commands[186],	/* M-X */
	(data_obj *) &commands[186],	/* M-Y */
	(data_obj *) &commands[186],	/* M-Z */
	(data_obj *) &commands[186],	/* M-[ */
	(data_obj *) &commands[186],	/* M-\ */
	(data_obj *) &commands[186],	/* M-] */
	(data_obj *) &commands[186],	/* M-^ */
	(data_obj *) &commands[186],	/* M-_ */
	(data_obj *) &commands[186],	/* M-` */
	(data_obj *) &commands[186],	/* M-a */
	(data_obj *) &commands[186],	/* M-b */
	(data_obj *) &commands[186],	/* M-c */
	(data_obj *) &commands[186],	/* M-d */
	(data_obj *) &commands[186],	/* M-e */
	(data_obj *) &commands[186],	/* M-f */
	(data_obj *) &commands[186],	/* M-g */
	(data_obj *) &commands[186],	/* M-h */
	(data_obj *) &commands[186],	/* M-i */
	(data_obj *) &commands[186],	/* M-j */
	(data_obj *) &commands[186],	/* M-k */
	(data_obj *) &commands[186],	/* M-l */
	(data_obj *) &commands[186],	/* M-m */
	(data_obj *) &commands[186],	/* M-n */
	(data_obj *) &commands[186],	/* M-o */
	(data_obj *) &commands[186],	/* M-p */
	(data_obj *) &commands[186],	/* M-q */
	(data_obj *) &commands[186],	/* M-r */
	(data_obj *) &commands[186],	/* M-s */
	(data_obj *) &commands[186],	/* M-t */
	(data_obj *) &commands[186],	/* M-u */
	(data_obj *) &commands[186],	/* M-v */
	(data_obj *) &commands[186],	/* M-w */
	(data_obj *) &commands[186],	/* M-x */
	(data_obj *) &commands[186],	/* M-y */
	(data_obj *) &commands[186],	/* M-z */
	(data_obj *) &commands[186],	/* M-{ */
	(data_obj *) &commands[186],	/* M-| */
	(data_obj *) &commands[186],	/* M-} */
	(data_obj *) &commands[186],	/* M-~ */
#ifdef PCNONASCII
	(data_obj *) NULL,		/* M-^? */
#else
	(data_obj *) &commands[186],	/* M-^? */
#endif
#endif /* NCHARS != 128 */
};

data_obj *EscKeys[NCHARS] = {
	(data_obj *) &commands[188],	/* ^@ */
	(data_obj *) NULL,		/* ^A */
	(data_obj *) &commands[10],	/* ^B */
	(data_obj *) NULL,		/* ^C */
	(data_obj *) &commands[65],	/* ^D */
	(data_obj *) NULL,		/* ^E */
	(data_obj *) &commands[90],	/* ^F */
	(data_obj *) NULL,		/* ^G */
	(data_obj *) NULL,		/* ^H */
	(data_obj *) NULL,		/* ^I */
	(data_obj *) NULL,		/* ^J */
	(data_obj *) &commands[109],	/* ^K */
	(data_obj *) &commands[32],	/* ^L */
	(data_obj *) NULL,		/* ^M */
	(data_obj *) &commands[88],	/* ^N */
	(data_obj *) NULL,		/* ^O */
	(data_obj *) &commands[8],	/* ^P */
	(data_obj *) NULL,		/* ^Q */
	(data_obj *) NULL,		/* ^R */
	(data_obj *) NULL,		/* ^S */
	(data_obj *) NULL,		/* ^T */
	(data_obj *) &commands[12],	/* ^U */
	(data_obj *) &commands[133],	/* ^V */
	(data_obj *) NULL,		/* ^W */
	(data_obj *) NULL,		/* ^X */
	(data_obj *) NULL,		/* ^Y */
	(data_obj *) NULL,		/* ^Z */
	(data_obj *) NULL,		/* ESC */
	(data_obj *) NULL,		/* ^\ */
	(data_obj *) NULL,		/* ^] */
	(data_obj *) NULL,		/* ^^ */
	(data_obj *) NULL,		/* ^_ */
	(data_obj *) NULL,		/*   */
	(data_obj *) NULL,		/* ! */
	(data_obj *) NULL,		/* " */
	(data_obj *) NULL,		/* # */
	(data_obj *) NULL,		/* $ */
	(data_obj *) NULL,		/* % */
	(data_obj *) NULL,		/* & */
	(data_obj *) NULL,		/* ' */
	(data_obj *) NULL,		/* ( */
	(data_obj *) NULL,		/* ) */
	(data_obj *) NULL,		/* * */
	(data_obj *) NULL,		/* + */
	(data_obj *) &commands[17],	/* , */
	(data_obj *) &commands[63],	/* - */
	(data_obj *) &commands[71],	/* . */
	(data_obj *) NULL,		/* / */
	(data_obj *) &commands[52],	/* 0 */
	(data_obj *) &commands[52],	/* 1 */
	(data_obj *) &commands[52],	/* 2 */
	(data_obj *) &commands[52],	/* 3 */
	(data_obj *) &commands[52],	/* 4 */
	(data_obj *) &commands[52],	/* 5 */
	(data_obj *) &commands[52],	/* 6 */
	(data_obj *) &commands[52],	/* 7 */
	(data_obj *) &commands[52],	/* 8 */
	(data_obj *) &commands[52],	/* 9 */
	(data_obj *) NULL,		/* : */
	(data_obj *) NULL,		/* ; */
	(data_obj *) &commands[15],	/* < */
	(data_obj *) NULL,		/* = */
	(data_obj *) &commands[69],	/* > */
	(data_obj *) &commands[49],	/* ? */
	(data_obj *) NULL,		/* @ */
	(data_obj *) &commands[11],	/* A */
	(data_obj *) &commands[13],	/* B */
	(data_obj *) &commands[27],	/* C */
	(data_obj *) &commands[105],	/* D */
	(data_obj *) &commands[91],	/* E */
	(data_obj *) &commands[92],	/* F */
	(data_obj *) &commands[95],	/* G */
	(data_obj *) NULL,		/* H */
	(data_obj *) &commands[122],	/* I */
	(data_obj *) &commands[80],	/* J */
	(data_obj *) &commands[113],	/* K */
	(data_obj *) &commands[28],	/* L */
	(data_obj *) &commands[86],	/* M */
	(data_obj *) NULL,		/* N */
	(data_obj *) NULL,		/* O */
	(data_obj *) NULL,		/* P */
	(data_obj *) &commands[155],	/* Q */
	(data_obj *) &commands[164],	/* R */
	(data_obj *) NULL,		/* S */
	(data_obj *) NULL,		/* T */
	(data_obj *) &commands[29],	/* U */
	(data_obj *) &commands[142],	/* V */
	(data_obj *) &commands[35],	/* W */
	(data_obj *) &commands[77],	/* X */
	(data_obj *) &commands[235],	/* Y */
	(data_obj *) &commands[167],	/* Z */
	(data_obj *) &commands[9],	/* [ */
	(data_obj *) &commands[47],	/* \ */
	(data_obj *) &commands[89],	/* ] */
	(data_obj *) NULL,		/* ^ */
	(data_obj *) NULL,		/* _ */
	(data_obj *) NULL,		/* ` */
	(data_obj *) &commands[11],	/* a */
	(data_obj *) &commands[13],	/* b */
	(data_obj *) &commands[27],	/* c */
	(data_obj *) &commands[105],	/* d */
	(data_obj *) &commands[91],	/* e */
	(data_obj *) &commands[92],	/* f */
	(data_obj *) &commands[95],	/* g */
	(data_obj *) NULL,		/* h */
	(data_obj *) &commands[122],	/* i */
	(data_obj *) &commands[80],	/* j */
	(data_obj *) &commands[113],	/* k */
	(data_obj *) &commands[28],	/* l */
	(data_obj *) &commands[86],	/* m */
	(data_obj *) NULL,		/* n */
	(data_obj *) NULL,		/* o */
	(data_obj *) NULL,		/* p */
	(data_obj *) &commands[155],	/* q */
	(data_obj *) &commands[164],	/* r */
	(data_obj *) NULL,		/* s */
	(data_obj *) NULL,		/* t */
	(data_obj *) &commands[29],	/* u */
	(data_obj *) &commands[142],	/* v */
	(data_obj *) &commands[35],	/* w */
	(data_obj *) &commands[77],	/* x */
	(data_obj *) &commands[235],	/* y */
	(data_obj *) &commands[167],	/* z */
	(data_obj *) NULL,		/* { */
	(data_obj *) NULL,		/* | */
	(data_obj *) NULL,		/* } */
	(data_obj *) &commands[121],	/* ~ */
	(data_obj *) &commands[106],	/* ^? */
#if NCHARS != 128
	(data_obj *) NULL,		/* M-^@ */
	(data_obj *) NULL,		/* M-^A */
	(data_obj *) NULL,		/* M-^B */
	(data_obj *) NULL,		/* M-^C */
	(data_obj *) NULL,		/* M-^D */
	(data_obj *) NULL,		/* M-^E */
	(data_obj *) NULL,		/* M-^F */
	(data_obj *) NULL,		/* M-^G */
	(data_obj *) NULL,		/* M-^H */
	(data_obj *) NULL,		/* M-^I */
	(data_obj *) NULL,		/* M-^J */
	(data_obj *) NULL,		/* M-^K */
	(data_obj *) NULL,		/* M-^L */
	(data_obj *) NULL,		/* M-^M */
	(data_obj *) NULL,		/* M-^N */
	(data_obj *) NULL,		/* M-^O */
	(data_obj *) NULL,		/* M-^P */
	(data_obj *) NULL,		/* M-^Q */
	(data_obj *) NULL,		/* M-^R */
	(data_obj *) NULL,		/* M-^S */
	(data_obj *) NULL,		/* M-^T */
	(data_obj *) NULL,		/* M-^U */
	(data_obj *) NULL,		/* M-^V */
	(data_obj *) NULL,		/* M-^W */
	(data_obj *) NULL,		/* M-^X */
	(data_obj *) NULL,		/* M-^Y */
	(data_obj *) NULL,		/* M-^Z */
	(data_obj *) NULL,		/* M-ESC */
	(data_obj *) NULL,		/* M-^\ */
	(data_obj *) NULL,		/* M-^] */
	(data_obj *) NULL,		/* M-^^ */
	(data_obj *) NULL,		/* M-^_ */
	(data_obj *) NULL,		/* M-  */
	(data_obj *) NULL,		/* M-! */
	(data_obj *) NULL,		/* M-" */
	(data_obj *) NULL,		/* M-# */
	(data_obj *) NULL,		/* M-$ */
	(data_obj *) NULL,		/* M-% */
	(data_obj *) NULL,		/* M-& */
	(data_obj *) NULL,		/* M-' */
	(data_obj *) NULL,		/* M-( */
	(data_obj *) NULL,		/* M-) */
	(data_obj *) NULL,		/* M-* */
	(data_obj *) NULL,		/* M-+ */
	(data_obj *) NULL,		/* M-, */
	(data_obj *) NULL,		/* M-- */
	(data_obj *) NULL,		/* M-. */
	(data_obj *) NULL,		/* M-/ */
	(data_obj *) NULL,		/* M-0 */
	(data_obj *) NULL,		/* M-1 */
	(data_obj *) NULL,		/* M-2 */
	(data_obj *) NULL,		/* M-3 */
	(data_obj *) NULL,		/* M-4 */
	(data_obj *) NULL,		/* M-5 */
	(data_obj *) NULL,		/* M-6 */
	(data_obj *) NULL,		/* M-7 */
	(data_obj *) NULL,		/* M-8 */
	(data_obj *) NULL,		/* M-9 */
	(data_obj *) NULL,		/* M-: */
	(data_obj *) NULL,		/* M-; */
	(data_obj *) NULL,		/* M-< */
	(data_obj *) NULL,		/* M-= */
	(data_obj *) NULL,		/* M-> */
	(data_obj *) NULL,		/* M-? */
	(data_obj *) NULL,		/* M-@ */
	(data_obj *) NULL,		/* M-A */
	(data_obj *) NULL,		/* M-B */
	(data_obj *) NULL,		/* M-C */
	(data_obj *) NULL,		/* M-D */
	(data_obj *) NULL,		/* M-E */
	(data_obj *) NULL,		/* M-F */
	(data_obj *) NULL,		/* M-G */
	(data_obj *) NULL,		/* M-H */
	(data_obj *) NULL,		/* M-I */
	(data_obj *) NULL,		/* M-J */
	(data_obj *) NULL,		/* M-K */
	(data_obj *) NULL,		/* M-L */
	(data_obj *) NULL,		/* M-M */
	(data_obj *) NULL,		/* M-N */
	(data_obj *) NULL,		/* M-O */
	(data_obj *) NULL,		/* M-P */
	(data_obj *) NULL,		/* M-Q */
	(data_obj *) NULL,		/* M-R */
	(data_obj *) NULL,		/* M-S */
	(data_obj *) NULL,		/* M-T */
	(data_obj *) NULL,		/* M-U */
	(data_obj *) NULL,		/* M-V */
	(data_obj *) NULL,		/* M-W */
	(data_obj *) NULL,		/* M-X */
	(data_obj *) NULL,		/* M-Y */
	(data_obj *) NULL,		/* M-Z */
	(data_obj *) NULL,		/* M-[ */
	(data_obj *) NULL,		/* M-\ */
	(data_obj *) NULL,		/* M-] */
	(data_obj *) NULL,		/* M-^ */
	(data_obj *) NULL,		/* M-_ */
	(data_obj *) NULL,		/* M-` */
	(data_obj *) NULL,		/* M-a */
	(data_obj *) NULL,		/* M-b */
	(data_obj *) NULL,		/* M-c */
	(data_obj *) NULL,		/* M-d */
	(data_obj *) NULL,		/* M-e */
	(data_obj *) NULL,		/* M-f */
	(data_obj *) NULL,		/* M-g */
	(data_obj *) NULL,		/* M-h */
	(data_obj *) NULL,		/* M-i */
	(data_obj *) NULL,		/* M-j */
	(data_obj *) NULL,		/* M-k */
	(data_obj *) NULL,		/* M-l */
	(data_obj *) NULL,		/* M-m */
	(data_obj *) NULL,		/* M-n */
	(data_obj *) NULL,		/* M-o */
	(data_obj *) NULL,		/* M-p */
	(data_obj *) NULL,		/* M-q */
	(data_obj *) NULL,		/* M-r */
	(data_obj *) NULL,		/* M-s */
	(data_obj *) NULL,		/* M-t */
	(data_obj *) NULL,		/* M-u */
	(data_obj *) NULL,		/* M-v */
	(data_obj *) NULL,		/* M-w */
	(data_obj *) NULL,		/* M-x */
	(data_obj *) NULL,		/* M-y */
	(data_obj *) NULL,		/* M-z */
	(data_obj *) NULL,		/* M-{ */
	(data_obj *) NULL,		/* M-| */
	(data_obj *) NULL,		/* M-} */
	(data_obj *) NULL,		/* M-~ */
	(data_obj *) NULL,		/* M-^? */
#endif /* NCHARS != 128 */
};

data_obj	*CtlxKeys[NCHARS] = {
	(data_obj *) NULL,		/* ^@ */
	(data_obj *) NULL,		/* ^A */
	(data_obj *) &commands[116],	/* ^B */
	(data_obj *) &commands[78],	/* ^C */
	(data_obj *) NULL,		/* ^D */
#ifdef SUBSHELL
	(data_obj *) &commands[33],	/* ^E */
#else
	(data_obj *) NULL,		/* ^E */
#endif
	(data_obj *) &commands[83],	/* ^F */
	(data_obj *) NULL,		/* ^G */
	(data_obj *) NULL,		/* ^H */
	(data_obj *) &commands[103],	/* ^I */
	(data_obj *) NULL,		/* ^J */
	(data_obj *) NULL,		/* ^K */
	(data_obj *) NULL,		/* ^L */
	(data_obj *) &commands[217],	/* ^M */
	(data_obj *) &commands[127],	/* ^N */
	(data_obj *) &commands[41],	/* ^O */
	(data_obj *) &commands[140],	/* ^P */
	(data_obj *) NULL,		/* ^Q */
	(data_obj *) &commands[212],	/* ^R */
	(data_obj *) &commands[166],	/* ^S */
	(data_obj *) &commands[208],	/* ^T */
	(data_obj *) NULL,		/* ^U */
	(data_obj *) &commands[212],	/* ^V */
	(data_obj *) &commands[215],	/* ^W */
	(data_obj *) &commands[74],	/* ^X */
	(data_obj *) NULL,		/* ^Y */
	(data_obj *) NULL,		/* ^Z */
	(data_obj *) NULL,		/* ESC */
	(data_obj *) &commands[166],	/* ^\ */
	(data_obj *) NULL,		/* ^] */
	(data_obj *) NULL,		/* ^^ */
	(data_obj *) NULL,		/* ^_ */
	(data_obj *) NULL,		/*   */
#ifdef SUBSHELL
	(data_obj *) &commands[190],	/* ! */
#else
	(data_obj *) NULL,		/* ! */
#endif
	(data_obj *) NULL,		/* " */
	(data_obj *) NULL,		/* # */
	(data_obj *) NULL,		/* $ */
	(data_obj *) NULL,		/* % */
	(data_obj *) NULL,		/* & */
	(data_obj *) NULL,		/* ' */
	(data_obj *) &commands[14],	/* ( */
	(data_obj *) &commands[68],	/* ) */
	(data_obj *) NULL,		/* * */
	(data_obj *) NULL,		/* + */
	(data_obj *) NULL,		/* , */
	(data_obj *) NULL,		/* - */
	(data_obj *) NULL,		/* . */
	(data_obj *) NULL,		/* / */
	(data_obj *) NULL,		/* 0 */
	(data_obj *) &commands[45],	/* 1 */
	(data_obj *) &commands[200],	/* 2 */
	(data_obj *) NULL,		/* 3 */
	(data_obj *) &commands[213],	/* 4 */
	(data_obj *) NULL,		/* 5 */
	(data_obj *) NULL,		/* 6 */
	(data_obj *) NULL,		/* 7 */
	(data_obj *) NULL,		/* 8 */
	(data_obj *) NULL,		/* 9 */
	(data_obj *) NULL,		/* : */
	(data_obj *) NULL,		/* ; */
	(data_obj *) NULL,		/* < */
	(data_obj *) NULL,		/* = */
	(data_obj *) NULL,		/* > */
	(data_obj *) &commands[50],	/* ? */
	(data_obj *) NULL,		/* @ */
	(data_obj *) NULL,		/* A */
	(data_obj *) &commands[175],	/* B */
	(data_obj *) NULL,		/* C */
	(data_obj *) &commands[43],	/* D */
	(data_obj *) &commands[75],	/* E */
	(data_obj *) NULL,		/* F */
	(data_obj *) NULL,		/* G */
	(data_obj *) NULL,		/* H */
	(data_obj *) NULL,		/* I */
	(data_obj *) NULL,		/* J */
	(data_obj *) &commands[42],	/* K */
	(data_obj *) NULL,		/* L */
	(data_obj *) NULL,		/* M */
	(data_obj *) &commands[130],	/* N */
	(data_obj *) &commands[143],	/* O */
	(data_obj *) &commands[143],	/* P */
	(data_obj *) NULL,		/* Q */
	(data_obj *) NULL,		/* R */
	(data_obj *) &commands[166],	/* S */
	(data_obj *) &commands[84],	/* T */
	(data_obj *) NULL,		/* U */
	(data_obj *) NULL,		/* V */
	(data_obj *) NULL,		/* W */
	(data_obj *) NULL,		/* X */
	(data_obj *) NULL,		/* Y */
	(data_obj *) NULL,		/* Z */
	(data_obj *) NULL,		/* [ */
	(data_obj *) NULL,		/* \ */
	(data_obj *) NULL,		/* ] */
	(data_obj *) &commands[98],	/* ^ */
	(data_obj *) NULL,		/* _ */
	(data_obj *) NULL,		/* ` */
	(data_obj *) NULL,		/* a */
	(data_obj *) &commands[175],	/* b */
	(data_obj *) NULL,		/* c */
	(data_obj *) &commands[43],	/* d */
	(data_obj *) &commands[75],	/* e */
	(data_obj *) NULL,		/* f */
	(data_obj *) NULL,		/* g */
	(data_obj *) NULL,		/* h */
	(data_obj *) NULL,		/* i */
	(data_obj *) NULL,		/* j */
	(data_obj *) &commands[42],	/* k */
	(data_obj *) NULL,		/* l */
	(data_obj *) NULL,		/* m */
	(data_obj *) &commands[130],	/* n */
	(data_obj *) &commands[143],	/* o */
	(data_obj *) &commands[143],	/* p */
	(data_obj *) NULL,		/* q */
	(data_obj *) NULL,		/* r */
	(data_obj *) &commands[166],	/* s */
	(data_obj *) &commands[84],	/* t */
	(data_obj *) NULL,		/* u */
	(data_obj *) NULL,		/* v */
	(data_obj *) NULL,		/* w */
	(data_obj *) NULL,		/* x */
	(data_obj *) NULL,		/* y */
	(data_obj *) NULL,		/* z */
	(data_obj *) NULL,		/* { */
	(data_obj *) NULL,		/* | */
	(data_obj *) NULL,		/* } */
	(data_obj *) NULL,		/* ~ */
	(data_obj *) &commands[111],	/* ^? */
#if NCHARS != 128
	(data_obj *) NULL,		/* M-^@ */
	(data_obj *) NULL,		/* M-^A */
	(data_obj *) NULL,		/* M-^B */
	(data_obj *) NULL,		/* M-^C */
	(data_obj *) NULL,		/* M-^D */
	(data_obj *) NULL,		/* M-^E */
	(data_obj *) NULL,		/* M-^F */
	(data_obj *) NULL,		/* M-^G */
	(data_obj *) NULL,		/* M-^H */
	(data_obj *) NULL,		/* M-^I */
	(data_obj *) NULL,		/* M-^J */
	(data_obj *) NULL,		/* M-^K */
	(data_obj *) NULL,		/* M-^L */
	(data_obj *) NULL,		/* M-^M */
	(data_obj *) NULL,		/* M-^N */
	(data_obj *) NULL,		/* M-^O */
	(data_obj *) NULL,		/* M-^P */
	(data_obj *) NULL,		/* M-^Q */
	(data_obj *) NULL,		/* M-^R */
	(data_obj *) NULL,		/* M-^S */
	(data_obj *) NULL,		/* M-^T */
	(data_obj *) NULL,		/* M-^U */
	(data_obj *) NULL,		/* M-^V */
	(data_obj *) NULL,		/* M-^W */
	(data_obj *) NULL,		/* M-^X */
	(data_obj *) NULL,		/* M-^Y */
	(data_obj *) NULL,		/* M-^Z */
	(data_obj *) NULL,		/* M-ESC */
	(data_obj *) NULL,		/* M-^\ */
	(data_obj *) NULL,		/* M-^] */
	(data_obj *) NULL,		/* M-^^ */
	(data_obj *) NULL,		/* M-^_ */
	(data_obj *) NULL,		/* M-  */
	(data_obj *) NULL,		/* M-! */
	(data_obj *) NULL,		/* M-" */
	(data_obj *) NULL,		/* M-# */
	(data_obj *) NULL,		/* M-$ */
	(data_obj *) NULL,		/* M-% */
	(data_obj *) NULL,		/* M-& */
	(data_obj *) NULL,		/* M-' */
	(data_obj *) NULL,		/* M-( */
	(data_obj *) NULL,		/* M-) */
	(data_obj *) NULL,		/* M-* */
	(data_obj *) NULL,		/* M-+ */
	(data_obj *) NULL,		/* M-, */
	(data_obj *) NULL,		/* M-- */
	(data_obj *) NULL,		/* M-. */
	(data_obj *) NULL,		/* M-/ */
	(data_obj *) NULL,		/* M-0 */
	(data_obj *) NULL,		/* M-1 */
	(data_obj *) NULL,		/* M-2 */
	(data_obj *) NULL,		/* M-3 */
	(data_obj *) NULL,		/* M-4 */
	(data_obj *) NULL,		/* M-5 */
	(data_obj *) NULL,		/* M-6 */
	(data_obj *) NULL,		/* M-7 */
	(data_obj *) NULL,		/* M-8 */
	(data_obj *) NULL,		/* M-9 */
	(data_obj *) NULL,		/* M-: */
	(data_obj *) NULL,		/* M-; */
	(data_obj *) NULL,		/* M-< */
	(data_obj *) NULL,		/* M-= */
	(data_obj *) NULL,		/* M-> */
	(data_obj *) NULL,		/* M-? */
	(data_obj *) NULL,		/* M-@ */
	(data_obj *) NULL,		/* M-A */
	(data_obj *) NULL,		/* M-B */
	(data_obj *) NULL,		/* M-C */
	(data_obj *) NULL,		/* M-D */
	(data_obj *) NULL,		/* M-E */
	(data_obj *) NULL,		/* M-F */
	(data_obj *) NULL,		/* M-G */
	(data_obj *) NULL,		/* M-H */
	(data_obj *) NULL,		/* M-I */
	(data_obj *) NULL,		/* M-J */
	(data_obj *) NULL,		/* M-K */
	(data_obj *) NULL,		/* M-L */
	(data_obj *) NULL,		/* M-M */
	(data_obj *) NULL,		/* M-N */
	(data_obj *) NULL,		/* M-O */
	(data_obj *) NULL,		/* M-P */
	(data_obj *) NULL,		/* M-Q */
	(data_obj *) NULL,		/* M-R */
	(data_obj *) NULL,		/* M-S */
	(data_obj *) NULL,		/* M-T */
	(data_obj *) NULL,		/* M-U */
	(data_obj *) NULL,		/* M-V */
	(data_obj *) NULL,		/* M-W */
	(data_obj *) NULL,		/* M-X */
	(data_obj *) NULL,		/* M-Y */
	(data_obj *) NULL,		/* M-Z */
	(data_obj *) NULL,		/* M-[ */
	(data_obj *) NULL,		/* M-\ */
	(data_obj *) NULL,		/* M-] */
	(data_obj *) NULL,		/* M-^ */
	(data_obj *) NULL,		/* M-_ */
	(data_obj *) NULL,		/* M-` */
	(data_obj *) NULL,		/* M-a */
	(data_obj *) NULL,		/* M-b */
	(data_obj *) NULL,		/* M-c */
	(data_obj *) NULL,		/* M-d */
	(data_obj *) NULL,		/* M-e */
	(data_obj *) NULL,		/* M-f */
	(data_obj *) NULL,		/* M-g */
	(data_obj *) NULL,		/* M-h */
	(data_obj *) NULL,		/* M-i */
	(data_obj *) NULL,		/* M-j */
	(data_obj *) NULL,		/* M-k */
	(data_obj *) NULL,		/* M-l */
	(data_obj *) NULL,		/* M-m */
	(data_obj *) NULL,		/* M-n */
	(data_obj *) NULL,		/* M-o */
	(data_obj *) NULL,		/* M-p */
	(data_obj *) NULL,		/* M-q */
	(data_obj *) NULL,		/* M-r */
	(data_obj *) NULL,		/* M-s */
	(data_obj *) NULL,		/* M-t */
	(data_obj *) NULL,		/* M-u */
	(data_obj *) NULL,		/* M-v */
	(data_obj *) NULL,		/* M-w */
	(data_obj *) NULL,		/* M-x */
	(data_obj *) NULL,		/* M-y */
	(data_obj *) NULL,		/* M-z */
	(data_obj *) NULL,		/* M-{ */
	(data_obj *) NULL,		/* M-| */
	(data_obj *) NULL,		/* M-} */
	(data_obj *) NULL,		/* M-~ */
	(data_obj *) NULL,		/* M-^? */
#endif /* NCHARS != 128 */
};

#ifdef PCNONASCII
/* These are codes generated by non-ASCII keys on an IBM-PC keyboard.
 * Codes marked with [E] are only generated by enhanced keyboards.
 * The codes 171 to 183 are synthesized by JOVE when it detects
 * shift + a code in 71 to 83.
 */
data_obj	*NonASCIIKeys[NCHARS] = {
	(data_obj *) NULL,		/* ^@ */
	(data_obj *) NULL,		/* ^A */
	(data_obj *) NULL,		/* ^B */
	(data_obj *) NULL,		/* ^C */
	(data_obj *) NULL,		/* ^D */
	(data_obj *) NULL,		/* ^E */
	(data_obj *) NULL,		/* ^F */
	(data_obj *) NULL,		/* ^G */
	(data_obj *) NULL,		/* ^H */
	(data_obj *) NULL,		/* ^I */
	(data_obj *) NULL,		/* ^J */
	(data_obj *) NULL,		/* ^K */
	(data_obj *) NULL,		/* ^L */
	(data_obj *) NULL,		/* ^M */
	(data_obj *) NULL,		/* ^N */
	(data_obj *) NULL,		/* ^O */
	(data_obj *) &commands[155],	/* ^P */
	(data_obj *) &commands[35],	/* ^Q */
	(data_obj *) &commands[91],	/* ^R */
	(data_obj *) &commands[164],	/* ^S */
	(data_obj *) NULL,		/* ^T */
	(data_obj *) &commands[235],	/* ^U */
	(data_obj *) &commands[29],	/* ^V */
	(data_obj *) &commands[122],	/* ^W */
	(data_obj *) NULL,		/* ^X */
	(data_obj *) NULL,		/* ^Y */
	(data_obj *) NULL,		/* ^Z */
	(data_obj *) NULL,		/* ESC */
	(data_obj *) NULL,		/* ^\ */
	(data_obj *) NULL,		/* ^] */
	(data_obj *) &commands[11],	/* ^^ */
	(data_obj *) NULL,		/* ^_ */
	(data_obj *) &commands[105],	/*   */
	(data_obj *) &commands[92],	/* ! */
	(data_obj *) &commands[95],	/* " */
	(data_obj *) NULL,		/* # */
	(data_obj *) &commands[80],	/* $ */
	(data_obj *) &commands[113],	/* % */
	(data_obj *) &commands[28],	/* & */
	(data_obj *) NULL,		/* ' */
	(data_obj *) NULL,		/* ( */
	(data_obj *) NULL,		/* ) */
	(data_obj *) NULL,		/* * */
	(data_obj *) NULL,		/* + */
	(data_obj *) &commands[167],	/* , */
	(data_obj *) &commands[77],	/* - */
	(data_obj *) &commands[27],	/* . */
	(data_obj *) &commands[142],	/* / */
	(data_obj *) &commands[13],	/* 0 */
	(data_obj *) NULL,		/* 1 */
	(data_obj *) &commands[86],	/* 2 */
	(data_obj *) NULL,		/* 3 */
	(data_obj *) NULL,		/* 4 */
	(data_obj *) NULL,		/* 5 */
	(data_obj *) NULL,		/* 6 */
	(data_obj *) NULL,		/* 7 */
	(data_obj *) NULL,		/* 8 */
	(data_obj *) NULL,		/* 9 */
	(data_obj *) NULL,		/* : */
	(data_obj *) NULL,		/* ; */
	(data_obj *) NULL,		/* < */
	(data_obj *) NULL,		/* = */
	(data_obj *) NULL,		/* > */
	(data_obj *) NULL,		/* ? */
	(data_obj *) NULL,		/* @ */
	(data_obj *) NULL,		/* A */
	(data_obj *) NULL,		/* B */
	(data_obj *) NULL,		/* C */
	(data_obj *) NULL,		/* D */
	(data_obj *) NULL,		/* E */
	(data_obj *) NULL,		/* F */
	(data_obj *) &commands[16],	/* G */
	(data_obj *) &commands[141],	/* H */
	(data_obj *) &commands[142],	/* I */
	(data_obj *) NULL,		/* J */
	(data_obj *) &commands[7],	/* K */
	(data_obj *) NULL,		/* L */
	(data_obj *) &commands[87],	/* M */
	(data_obj *) NULL,		/* N */
	(data_obj *) &commands[70],	/* O */
	(data_obj *) &commands[128],	/* P */
	(data_obj *) &commands[129],	/* Q */
	(data_obj *) &commands[132],	/* R */
	(data_obj *) NULL,		/* S */
	(data_obj *) NULL,		/* T */
	(data_obj *) NULL,		/* U */
	(data_obj *) NULL,		/* V */
	(data_obj *) NULL,		/* W */
	(data_obj *) NULL,		/* X */
	(data_obj *) NULL,		/* Y */
	(data_obj *) NULL,		/* Z */
	(data_obj *) NULL,		/* [ */
	(data_obj *) NULL,		/* \ */
	(data_obj *) NULL,		/* ] */
	(data_obj *) NULL,		/* ^ */
	(data_obj *) NULL,		/* _ */
	(data_obj *) NULL,		/* ` */
	(data_obj *) NULL,		/* a */
	(data_obj *) NULL,		/* b */
	(data_obj *) NULL,		/* c */
	(data_obj *) NULL,		/* d */
	(data_obj *) NULL,		/* e */
	(data_obj *) NULL,		/* f */
	(data_obj *) NULL,		/* g */
	(data_obj *) NULL,		/* h */
	(data_obj *) NULL,		/* i */
	(data_obj *) NULL,		/* j */
	(data_obj *) NULL,		/* k */
	(data_obj *) NULL,		/* l */
	(data_obj *) NULL,		/* m */
	(data_obj *) NULL,		/* n */
	(data_obj *) NULL,		/* o */
	(data_obj *) NULL,		/* p */
	(data_obj *) NULL,		/* q */
	(data_obj *) NULL,		/* r */
	(data_obj *) &commands[13],	/* s */
	(data_obj *) &commands[92],	/* t */
	(data_obj *) &commands[69],	/* u */
	(data_obj *) &commands[130],	/* v */
	(data_obj *) &commands[15],	/* w */
	(data_obj *) &commands[176],	/* x */
	(data_obj *) &commands[178],	/* y */
	(data_obj *) &commands[179],	/* z */
	(data_obj *) &commands[180],	/* { */
	(data_obj *) &commands[181],	/* | */
	(data_obj *) &commands[182],	/* } */
	(data_obj *) &commands[183],	/* ~ */
	(data_obj *) &commands[184],	/* ^? */
	(data_obj *) &commands[185],	/* M-^@ */
	(data_obj *) &commands[177],	/* M-^A */
	(data_obj *) NULL,		/* M-^B */
	(data_obj *) NULL,		/* M-^C */
	(data_obj *) &commands[143],	/* M-^D */
	(data_obj *) NULL,		/* M-^E */
	(data_obj *) NULL,		/* M-^F */
	(data_obj *) NULL,		/* M-^G */
	(data_obj *) NULL,		/* M-^H */
	(data_obj *) NULL,		/* M-^I */
	(data_obj *) NULL,		/* M-^J */
	(data_obj *) NULL,		/* M-^K */
	(data_obj *) NULL,		/* M-^L */
	(data_obj *) NULL,		/* M-^M */
	(data_obj *) NULL,		/* M-^N */
	(data_obj *) NULL,		/* M-^O */
	(data_obj *) NULL,		/* M-^P */
	(data_obj *) NULL,		/* M-^Q */
	(data_obj *) NULL,		/* M-^R */
	(data_obj *) NULL,		/* M-^S */
	(data_obj *) NULL,		/* M-^T */
	(data_obj *) NULL,		/* M-^U */
	(data_obj *) NULL,		/* M-^V */
	(data_obj *) NULL,		/* M-^W */
	(data_obj *) NULL,		/* M-^X */
	(data_obj *) NULL,		/* M-^Y */
	(data_obj *) NULL,		/* M-^Z */
	(data_obj *) NULL,		/* M-ESC */
	(data_obj *) NULL,		/* M-^\ */
	(data_obj *) NULL,		/* M-^] */
	(data_obj *) NULL,		/* M-^^ */
	(data_obj *) NULL,		/* M-^_ */
	(data_obj *) NULL,		/* M-  */
	(data_obj *) NULL,		/* M-! */
	(data_obj *) NULL,		/* M-" */
	(data_obj *) NULL,		/* M-# */
	(data_obj *) NULL,		/* M-$ */
	(data_obj *) NULL,		/* M-% */
	(data_obj *) NULL,		/* M-& */
	(data_obj *) NULL,		/* M-' */
	(data_obj *) NULL,		/* M-( */
	(data_obj *) NULL,		/* M-) */
	(data_obj *) NULL,		/* M-* */
	(data_obj *) NULL,		/* M-+ */
	(data_obj *) NULL,		/* M-, */
	(data_obj *) NULL,		/* M-- */
	(data_obj *) NULL,		/* M-. */
	(data_obj *) NULL,		/* M-/ */
	(data_obj *) NULL,		/* M-0 */
	(data_obj *) NULL,		/* M-1 */
	(data_obj *) NULL,		/* M-2 */
	(data_obj *) NULL,		/* M-3 */
	(data_obj *) NULL,		/* M-4 */
	(data_obj *) NULL,		/* M-5 */
	(data_obj *) NULL,		/* M-6 */
	(data_obj *) NULL,		/* M-7 */
	(data_obj *) NULL,		/* M-8 */
	(data_obj *) NULL,		/* M-9 */
	(data_obj *) NULL,		/* M-: */
	(data_obj *) NULL,		/* M-; */
	(data_obj *) NULL,		/* M-< */
	(data_obj *) NULL,		/* M-= */
	(data_obj *) NULL,		/* M-> */
	(data_obj *) NULL,		/* M-? */
	(data_obj *) NULL,		/* M-@ */
	(data_obj *) NULL,		/* M-A */
	(data_obj *) NULL,		/* M-B */
	(data_obj *) NULL,		/* M-C */
	(data_obj *) NULL,		/* M-D */
	(data_obj *) NULL,		/* M-E */
	(data_obj *) NULL,		/* M-F */
	(data_obj *) NULL,		/* M-G */
	(data_obj *) NULL,		/* M-H */
	(data_obj *) NULL,		/* M-I */
	(data_obj *) NULL,		/* M-J */
	(data_obj *) NULL,		/* M-K */
	(data_obj *) NULL,		/* M-L */
	(data_obj *) NULL,		/* M-M */
	(data_obj *) NULL,		/* M-N */
	(data_obj *) NULL,		/* M-O */
	(data_obj *) NULL,		/* M-P */
	(data_obj *) NULL,		/* M-Q */
	(data_obj *) NULL,		/* M-R */
	(data_obj *) NULL,		/* M-S */
	(data_obj *) NULL,		/* M-T */
	(data_obj *) NULL,		/* M-U */
	(data_obj *) NULL,		/* M-V */
	(data_obj *) NULL,		/* M-W */
	(data_obj *) NULL,		/* M-X */
	(data_obj *) NULL,		/* M-Y */
	(data_obj *) NULL,		/* M-Z */
	(data_obj *) NULL,		/* M-[ */
	(data_obj *) NULL,		/* M-\ */
	(data_obj *) NULL,		/* M-] */
	(data_obj *) NULL,		/* M-^ */
	(data_obj *) NULL,		/* M-_ */
	(data_obj *) NULL,		/* M-` */
	(data_obj *) NULL,		/* M-a */
	(data_obj *) NULL,		/* M-b */
	(data_obj *) NULL,		/* M-c */
	(data_obj *) NULL,		/* M-d */
	(data_obj *) NULL,		/* M-e */
	(data_obj *) NULL,		/* M-f */
	(data_obj *) NULL,		/* M-g */
	(data_obj *) NULL,		/* M-h */
	(data_obj *) NULL,		/* M-i */
	(data_obj *) NULL,		/* M-j */
	(data_obj *) NULL,		/* M-k */
	(data_obj *) NULL,		/* M-l */
	(data_obj *) NULL,		/* M-m */
	(data_obj *) NULL,		/* M-n */
	(data_obj *) NULL,		/* M-o */
	(data_obj *) NULL,		/* M-p */
	(data_obj *) NULL,		/* M-q */
	(data_obj *) NULL,		/* M-r */
	(data_obj *) NULL,		/* M-s */
	(data_obj *) NULL,		/* M-t */
	(data_obj *) NULL,		/* M-u */
	(data_obj *) NULL,		/* M-v */
	(data_obj *) NULL,		/* M-w */
	(data_obj *) NULL,		/* M-x */
	(data_obj *) NULL,		/* M-y */
	(data_obj *) NULL,		/* M-z */
	(data_obj *) NULL,		/* M-{ */
	(data_obj *) NULL,		/* M-| */
	(data_obj *) NULL,		/* M-} */
	(data_obj *) NULL,		/* M-~ */
	(data_obj *) NULL,		/* M-^? */
};
#endif /* PCNONASCII */
